@@ -7,8 +7,8 @@ bcs asub cromwell gatk-job\
    --input_from_file_WDL src/haplotypecaller-gvcf-gatk4.wdl\
    --input_from_file_WORKFLOW_INPUTS src/haplotypecaller-gvcf-gatk4.hg38.wgs.inputs.json\
    --input_from_file_WORKFLOW_OPTIONS src/generic.batchcompute-papi.options.json\
-   --input_WORKING_DIR #{{DEFAULT_OSS_PATH}}gatk4_worker_dir/\
-   --output_OUTPUTS_DIR #{{DEFAULT_OSS_PATH}}gatk4_outputs/\
+   --input_WORKING_DIR #{{DEFAULT_OSS_PATH}}gatk4/gatk4-germline-snps-indels/worker_dir/\
+   --output_OUTPUTS_DIR #{{DEFAULT_OSS_PATH}}gatk4/gatk4-germline-snps-indels/outputs/\
    -t #{{INSTANCE_TYPE:4:8}} -d cloud_efficiency
 
 
