@@ -7,7 +7,8 @@ bcs asub cromwell gatk-job\
    --input_from_file_WDL src/processing-for-variant-discovery-gatk4.wdl\
    --input_from_file_WORKFLOW_INPUTS src/processing-for-variant-discovery-gatk4.hg38.wgs.inputs.json\
    --input_from_file_WORKFLOW_OPTIONS src/generic.batchcompute-papi.options.json\
-   --input_WORKING_DIR oss://your-bucket/gatk4_worker_dir/\
-   --output_OUTPUTS_DIR oss://your-bucket/gatk4_outputs/\
+   --input_WORKING_DIR #{{DEFAULT_OSS_PATH}}gatk4/gatk4-data-processing/worker_dir/\
+   --output_OUTPUTS_DIR #{{DEFAULT_OSS_PATH}}gatk4/gatk4-data-processing/outputs/\
    -t #{{INSTANCE_TYPE:4:8}} -d cloud_efficiency
 
+
