@@ -81,6 +81,9 @@ def check(jobId):
     ins_types = (client.list_instance_types() or [])
     for n in ins_types:
         ins_map[n.get('name')]=n
+    spot_ins_types = (client.list_spot_instance_types() or [])
+    for n in spot_ins_types:
+        ins_map[n.get('name')] = n
 
 
 
@@ -94,11 +97,14 @@ def check(jobId):
 
 
             coreHours = 0
+            totalCoreHours = 0
             billingArr = []
             for (taskName, subJobs) in meta['calls'].items():
-                hours = 0
+                totalHours= 0
                 for item in subJobs:
-                    hours += getHours(item['start'], item['end'])
+
+                    hours = getHours(item['start'], item['end'])
+                    totalHours += hours
 
                     cpu=0
                     if item['runtimeAttributes']['cluster']:
@@ -113,11 +119,12 @@ def check(jobId):
                        cpu = ins_map[item['runtimeAttributes']['instanceType']]['cpu']
 
 
-                coreHours +=  hours * cpu
-                billingArr.append({'task': taskName, 'hours': hours, 'count': 1, 'cpu': cpu})
-            list2table.print_table(billingArr, ['task', 'cpu', 'count', 'hours'])
+                coreHours = totalHours * cpu
+                totalCoreHours+= coreHours
+                billingArr.append({'task': taskName,'count': len(subJobs), 'hours': totalHours,  'cpu': cpu, 'coreHours':coreHours})
+            list2table.print_table(billingArr, ['task', 'count', 'cpu', 'hours', 'coreHours'])
 
-            print('%s: %s' % (green('Total core * hours'), coreHours))
+            print('%s: %s' % (green('Total core * hours'), totalCoreHours))
 
         except Exception as ee:
             pass
