@@ -9,8 +9,14 @@ import json
 def create_cluster(clusterName, image=None, type=None, nodes=1, description='', user_data=None, env=None, disk=None,
                    notification_endpoint=None, notification_topic=None, notification_events=None,
                    mount=None, nas_access_group=None, nas_file_system=None, resource_type='OnDemand',
-                    vpc_cidr_block=None, vpc_id=None, file_path=None, schedule_type=None,
+                   vpc_cidr_block=None, vpc_id=None, file_path=None, schedule_type=None,
+                   locale='GBK',
+                   lock=False,
                    no_cache_support=False,
+                   cache_block_size=0,
+                   cache_total_size=0,
+                   refresh_time_out=0,
+                   nas_meta_cache=False,
                    spot_price_limit=None,
                    show_json=False):
     cluster_desc = {}
@@ -72,7 +78,6 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
         if disk:
             cluster_desc['Configs']['Disks']=disk
 
-
         if mount:
             extend_mount(cluster_desc, mount)
 
@@ -81,9 +86,26 @@ def create_cluster(clusterName, image=None, type=None, nodes=1, description='',
         if nas_file_system:
             cluster_desc['Configs']['Mounts']['NAS']['FileSystem'] = nas_file_system.split(',')
 
+        if locale:
+            cluster_desc['Configs']['Mounts']['Locale'] = locale
+
+        if lock:
+            cluster_desc['Configs']['Mounts']['Lock'] = lock
+
         if no_cache_support:
             cluster_desc['Configs']['Mounts']['CacheSupport'] = not no_cache_support
 
+        if cache_block_size:
+            cluster_desc['Configs']['Mounts']['CacheBlockSize'] = cache_block_size
+
+        if cache_total_size:
+            cluster_desc['Configs']['Mounts']['CacheTotalSize'] = cache_total_size
+
+        if refresh_time_out:
+            cluster_desc['Configs']['Mounts']['ReferchTimeOut'] = refresh_time_out
+
+        if nas_meta_cache:
+            cluster_desc['Configs']['Mounts']['NasMetaCache'] = nas_meta_cache
 
          # notification
         cluster_desc['Notification']={'Topic':{}}
@@ -202,3 +224,9 @@ def trans_env(env):
 def trans_disk(disk):
     return util.trans_disk(disk)
 
+def trans_to_int(size):
+    try:
+        size = int(size)
+        return size if size >= 0 else 0
+    except:
+        return 0
