@@ -25,7 +25,7 @@ def all(*args, **kwargs):
         show_config()
     else:
         for k, v in kwargs.items():
-            if handlFunc.has_key(k):
+            if handlFunc.get(k):
                 handlFunc[k](v)
         print(green('done'))
 
