@@ -147,6 +147,7 @@ def getJobDetail(jobId, descOnly, show_json=False):
         print('  %s: %s' % (blue('Description'), desc.get('Description') or ''))
 
 
+
     # task list
     tasks = client.list_tasks(jobId)
 
@@ -154,27 +155,33 @@ def getJobDetail(jobId, descOnly, show_json=False):
 
     arr = formater.format_date_in_arr(arr, ['StartTime', 'EndTime'])
 
-    # calc deps
-    deps = util.get_task_deps(desc.get('DAG'))
-    matric = dag.sortIndex(deps)
+    if desc.get('Type') == 'DAG':
+        ##########################  dag #############################
+        # calc deps
+        deps = util.get_task_deps(desc.get('DAG'))
+        matric = dag.sortIndex(deps)
 
-    # dag
-    if len(arr)>1:
-        print('%s' % bold(magenta('DAG:')))
-        dag.draw(deps, matric)
+        # dag
+        if len(arr)>1:
+            print('%s' % bold(magenta('DAG:')))
+            dag.draw(deps, matric)
 
-     # task list continue
-    for item in arr:
-        item['Counts'] = calc_metric_count(item['InstanceMetrics'])
-        task_desc = desc.DAG.Tasks[item['TaskName']]
+         # task list continue
+        for item in arr:
+            item['Counts'] = calc_metric_count(item['InstanceMetrics'])
+            task_desc = desc.DAG.Tasks[item['TaskName']]
 
-        item['Cluster'] = util.get_cluster_str(task_desc)
+            item['Cluster'] = util.get_cluster_str(task_desc)
+
+        arr = util.sort_task_by_deps(arr, matric)
+
+        ##########################  dag end #############################
 
-    arr = util.sort_task_by_deps(arr, matric)
 
     # cache
     result_cache.save(arr, 'TaskName', 'tasks')
 
+
     print('%s' % bold(magenta('Tasks:')))
     list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime', 'Elapsed','Cluster'])
 
@@ -184,6 +191,9 @@ def getJobDetail(jobId, descOnly, show_json=False):
 
     print(white('\n  type "%s j <jobId|No.> <taskName|No.>" to show task detail\n' % CMD))
 
+
+
+
 def getTaskDetail(jobId, taskName, descOnly, show_json=False):
     jobId = result_cache.get(jobId, 'jobs')
     taskName = result_cache.get(taskName, 'tasks')
@@ -198,126 +208,155 @@ def getTaskDetail(jobId, taskName, descOnly, show_json=False):
 
 
     taskInfo['Counts'] = calc_metric_count(taskInfo['InstanceMetrics'])
-    taskDesc = jobDesc.DAG.Tasks[taskInfo['TaskName']]
 
-    if descOnly or show_json:
-        print(taskDesc)
-        return
+    if jobDesc.get('Type')=='DAG':
 
-    taskInfo['Cluster'] = util.get_cluster_str(taskDesc)
+        taskDesc = jobDesc.DAG.Tasks[taskInfo['TaskName']]
 
-    arr = formater.format_date_in_arr([taskInfo], [ 'StartTime', 'EndTime'])
+        if descOnly or show_json:
+            print(taskDesc)
+            return
+
+        taskInfo['Cluster'] = util.get_cluster_str(taskDesc)
+
+        arr = formater.format_date_in_arr([taskInfo], [ 'StartTime', 'EndTime'])
 
 
-    # task
-    print('%s' % bold(magenta('Task:')))
-    clusterTitle = 'Cluster'
-    if taskDesc.get('AutoCluster'):
-        clusterTitle = 'AutoCluster %s' % (yellow('(ReserveOnFail)') if taskDesc['AutoCluster'].get('ReserveOnFail') else '')
+        # task
+        print('%s' % bold(magenta('Task:')))
+        clusterTitle = 'Cluster'
+        if taskDesc.get('AutoCluster'):
+            clusterTitle = 'AutoCluster %s' % (yellow('(ReserveOnFail)') if taskDesc['AutoCluster'].get('ReserveOnFail') else '')
 
-    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapsed', ('Cluster',clusterTitle)], show_no=False)
+        list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapsed', ('Cluster',clusterTitle)], show_no=False)
 
-    # task description
-    print('%s' % bold(magenta('Task Description:')))
+        # task description
+        print('%s' % bold(magenta('Task Description:')))
 
-    # disks
-    if taskDesc.get('AutoCluster'):
-        disks = taskDesc['AutoCluster']['Configs']['Disks']
-        print(blue('Disks:'))
-        if disks.get('SystemDisk'):
-            print('  |--System Disk: %s (%s) %sGB' % ('/', blue(disks['SystemDisk']['Type']), disks['SystemDisk']['Size']))
-        if disks.get('DataDisk') and disks['DataDisk'].get('MountPoint'):
-            print('  |--Data Disk: %s (%s) %sGB' % (
-            disks['DataDisk']['MountPoint'], blue(disks['DataDisk']['Type']), disks['DataDisk']['Size']))
+        # disks
+        if taskDesc.get('AutoCluster'):
+            disks = taskDesc['AutoCluster']['Configs']['Disks']
+            print(blue('Disks:'))
+            if disks.get('SystemDisk'):
+                print('  |--System Disk: %s (%s) %sGB' % ('/', blue(disks['SystemDisk']['Type']), disks['SystemDisk']['Size']))
+            if disks.get('DataDisk') and disks['DataDisk'].get('MountPoint'):
+                print('  |--Data Disk: %s (%s) %sGB' % (
+                disks['DataDisk']['MountPoint'], blue(disks['DataDisk']['Type']), disks['DataDisk']['Size']))
 
-        # mounts
-        mounts = taskDesc['AutoCluster']['Configs']['Mounts']
-        print('%s (Locale: %s , Lock: %s , CacheSupport: %s)' % (
-        blue('Mounts:'), mounts.get('Locale'), mounts.get('Lock'), mounts.get('CacheSupport')))
+            # mounts
+            mounts = taskDesc['AutoCluster']['Configs']['Mounts']
+            print('%s (Locale: %s , Lock: %s , CacheSupport: %s)' % (
+            blue('Mounts:'), mounts.get('Locale'), mounts.get('Lock'), mounts.get('CacheSupport')))
 
-        entries = mounts.get('Entries')
-        if entries:
-            for ent in entries:
-                print('  |--%s %s %s' % (ent['Destination'], blue('<-'), green(ent['Source'])))
+            entries = mounts.get('Entries')
+            if entries:
+                for ent in entries:
+                    print('  |--%s %s %s' % (ent['Destination'], blue('<-'), green(ent['Source'])))
 
-        nas = mounts.get('  Nas')
-        if nas:
-            if nas.get('AccessGroup'):
-                print('    AccessGroup: %s' % (','.join(nas['AccessGroup'])))
-            if nas.get('FileSystem'):
-                print('    FileSystem: %s' % (','.join(nas['FileSystem'])))
+            nas = mounts.get('  Nas')
+            if nas:
+                if nas.get('AccessGroup'):
+                    print('    AccessGroup: %s' % (','.join(nas['AccessGroup'])))
+                if nas.get('FileSystem'):
+                    print('    FileSystem: %s' % (','.join(nas['FileSystem'])))
 
-        oss = mounts.get('OSS')
-        if oss:
-            if oss.get('AccessKeyId'):
-                print('    AccessKeyId: %s' % nas['AccessGroup'])
-            if oss.get('AccessKeySecret'):
-                print('    AccessKeySecret: %s' % nas['AccessKeySecret'])
-            if oss.get('AccessSecurityToken'):
-                print('    AccessSecurityToken: %s' % nas['AccessSecurityToken'])
+            oss = mounts.get('OSS')
+            if oss:
+                if oss.get('AccessKeyId'):
+                    print('    AccessKeyId: %s' % nas['AccessGroup'])
+                if oss.get('AccessKeySecret'):
+                    print('    AccessKeySecret: %s' % nas['AccessKeySecret'])
+                if oss.get('AccessSecurityToken'):
+                    print('    AccessSecurityToken: %s' % nas['AccessSecurityToken'])
 
 
 
 
-        # Networks
-        nw = taskDesc['AutoCluster']['Configs'].get('Networks')
-        if nw:
-            print(blue('Networks:'))
+            # Networks
+            nw = taskDesc['AutoCluster']['Configs'].get('Networks')
+            if nw:
+                print(blue('Networks:'))
 
-            classic = taskDesc['AutoCluster']['Configs']['Networks'].get('Classic')
-            if classic:
-                print('  |--Classic:')
-                if classic.get('AllowIpAddress'):
-                    print('     AllowIpAddress: %s' % ','.join(classic['AllowIpAddress']))
-                if classic.get('AllowIpAddressEgress'):
-                    print('     AllowIpAddressEgress: %s' % ','.join(classic['AllowIpAddressEgress']))
-                if classic.get('AllowSecurityGroup'):
-                    print('     AllowSecurityGroup: %s' % ','.join(classic['AllowSecurityGroup']))
-                if classic.get('AllowSecurityGroupEgress'):
-                    print('     AllowSecurityGroupEgress: %s' % ','.join(classic['AllowSecurityGroupEgress']))
+                classic = taskDesc['AutoCluster']['Configs']['Networks'].get('Classic')
+                if classic:
+                    print('  |--Classic:')
+                    if classic.get('AllowIpAddress'):
+                        print('     AllowIpAddress: %s' % ','.join(classic['AllowIpAddress']))
+                    if classic.get('AllowIpAddressEgress'):
+                        print('     AllowIpAddressEgress: %s' % ','.join(classic['AllowIpAddressEgress']))
+                    if classic.get('AllowSecurityGroup'):
+                        print('     AllowSecurityGroup: %s' % ','.join(classic['AllowSecurityGroup']))
+                    if classic.get('AllowSecurityGroupEgress'):
+                        print('     AllowSecurityGroupEgress: %s' % ','.join(classic['AllowSecurityGroupEgress']))
 
-            vpc = taskDesc['AutoCluster']['Configs']['Networks'].get('VPC')
-            if vpc:
-                print('  |--VPC:')
-                for (k, v) in vpc.items():
-                    if v:
-                        print('     %s : %s' % (k, v))
-    print('')
+                vpc = taskDesc['AutoCluster']['Configs']['Networks'].get('VPC')
+                if vpc:
+                    print('  |--VPC:')
+                    for (k, v) in vpc.items():
+                        if v:
+                            print('     %s : %s' % (k, v))
+        print('')
 
-    command = formater.to_dict(taskDesc.Parameters.Command)
+        command = formater.to_dict(taskDesc.Parameters.Command)
 
-    print('%s: %s    %s: %s    %s: %s' %(  blue('Timeout'), taskDesc.Timeout, blue('MaxRetryCount'), taskDesc.MaxRetryCount, blue('WriteSupport'), taskDesc.WriteSupport, ))
+        print('%s: %s    %s: %s    %s: %s' %(  blue('Timeout'), taskDesc.Timeout, blue('MaxRetryCount'), taskDesc.MaxRetryCount, blue('WriteSupport'), taskDesc.WriteSupport, ))
 
-    print(blue('Command:'))
-    print('  %s: %s' % (blue('CommandLine') , command.get('CommandLine')))
-    if command.get('PackagePath'):
-        print('  %s: %s' % (blue('PackagePath') , command.get('PackagePath')))
-    if command.get('EnvVars'):
-        print(blue('  EnvVars:'))
-        for (k,v) in command['EnvVars'].items():
-            print('    %s: %s' % (bold(k),v))
+        print(blue('Command:'))
+        print('  %s: %s' % (blue('CommandLine') , command.get('CommandLine')))
+        if command.get('PackagePath'):
+            print('  %s: %s' % (blue('PackagePath') , command.get('PackagePath')))
+        if command.get('EnvVars'):
+            print(blue('  EnvVars:'))
+            for (k,v) in command['EnvVars'].items():
+                print('    %s: %s' % (bold(k),v))
 
 
 
-    print('%s: %s' % ( blue('InputMappingConfig:'), json.dumps(formater.to_dict(taskDesc.Parameters.InputMappingConfig)) ))
-    print('%s: %s' % ( blue('StdoutRedirectPath:'), taskDesc.Parameters.StdoutRedirectPath ))
-    print('%s: %s' % ( blue('StderrRedirectPath:'), taskDesc.Parameters.StderrRedirectPath ))
+        print('%s: %s' % ( blue('InputMappingConfig:'), json.dumps(formater.to_dict(taskDesc.Parameters.InputMappingConfig)) ))
+        print('%s: %s' % ( blue('StdoutRedirectPath:'), taskDesc.Parameters.StdoutRedirectPath ))
+        print('%s: %s' % ( blue('StderrRedirectPath:'), taskDesc.Parameters.StderrRedirectPath ))
 
 
-    if taskDesc.InputMapping:
-        print(blue('InputMapping:'))
-        for (k,v) in taskDesc.InputMapping.items():
-            print('  %s: %s' % (bold(k),v))
+        if taskDesc.InputMapping:
+            print(blue('InputMapping:'))
+            for (k,v) in taskDesc.InputMapping.items():
+                print('  %s: %s' % (bold(k),v))
+
+        if taskDesc.OutputMapping:
+            print(blue('OutputMapping:'))
+            for (k,v) in taskDesc.OutputMapping.items():
+                print('  %s: %s' % (bold(k),v))
+
+        if taskDesc.LogMapping:
+            print(blue('LogMapping:'))
+            for (k,v) in taskDesc.LogMapping.items():
+                print('  %s: %s' % (bold(k),v))
+
+    elif jobDesc.get('Type')=='App':
+
+        appDesc = jobDesc.get('App')
+
+        print(magenta('App:'))
+
+        print('%s: %s' % ( blue('AppName'), appDesc.AppName ))
+
+        print(blue('Inputs:'))
+        for (k, v) in appDesc.Inputs.items():
+            print('  %s: %s' % (bold(k), v))
+
+        print(blue('Outputs:'))
+        for (k, v) in appDesc.Outputs.items():
+            print('  %s: %s' % (bold(k), v))
+
+        print(blue('Config:'))
+        for (k, v) in appDesc.Config.items():
+            print('  %s: %s' % (bold(k), v))
+
+        print(blue('Logging:'))
+        for (k, v) in appDesc.Logging.items():
+            print('  %s: %s' % (bold(k), v))
 
-    if taskDesc.OutputMapping:
-        print(blue('OutputMapping:'))
-        for (k,v) in taskDesc.OutputMapping.items():
-            print('  %s: %s' % (bold(k),v))
 
-    if taskDesc.LogMapping:
-        print(blue('LogMapping:'))
-        for (k,v) in taskDesc.LogMapping.items():
-            print('  %s: %s' % (bold(k),v))
 
     # instances
 
@@ -359,7 +398,6 @@ def getInstanceDetail(jobId, taskName, instanceId, show_json=False):
         print(formater.to_dict(ins))
         return
 
-
     arr = formater.format_date_in_arr([formater.to_dict(ins)], ['CreationTime', 'StartTime', 'EndTime'])
 
     print('%s' % bold(magenta('Instance:')))
@@ -371,23 +409,34 @@ def getInstanceDetail(jobId, taskName, instanceId, show_json=False):
     print('%s: %s' % (blue('StdoutRedirectPath'), stdout_path ))
     print('%s: %s' % (blue('StderrRedirectPath'), stderr_path ))
 
-    if ins.Result and ins.Result.Detail:
+
+    if ins.Result and ins.Result.ErrorCode:
         print('%s' % bold(magenta('Result:')))
         print('  %s: %s' % (blue('ExitCode'), ins.Result.ExitCode ))
         print('  %s: %s' % (blue('ErrorCode'), red(ins.Result.ErrorCode) ))
         print('  %s: %s' % (blue('ErrorMessage'), red(ins.Result.ErrorMessage) ))
         print('  %s: %s' % (blue('Detail'), red(ins.Result.Detail) ))
 
+    if ins.Error and ins.Error.Code:
+        print('%s' % bold(magenta('Error:')))
+        print('  %s: %s' % (blue('Code'), ins.Error.Code))
+        print('  %s: %s' % (blue('Message'), red(ins.Error.Message)))
+
+    if ins.Outputs:
+        print(ins.Outputs)
+
+    try:
+        showLog(ins.StdoutRedirectPath, jobId, taskName, instanceId, 'stdout')
+    except Exception as e:
+        if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
+            raise e
+
     try:
         showLog(ins.StderrRedirectPath,jobId,taskName, instanceId, 'stderr')
     except Exception as e:
         if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
             raise e
-        try:
-            showLog(ins.StdoutRedirectPath,jobId,taskName, instanceId, 'stdout')
-        except Exception as e:
-            if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
-                raise e
+
 
     print(white('\n  If you want to download these logs, type "%s log -h" for more\n' % CMD))
 
@@ -395,13 +444,15 @@ def showLog(osspath, jobId, taskName, instanceId, logType):
 
     osspath = formater.fix_log_path(osspath ,jobId,taskName, instanceId, logType)
 
-    content = oss_client.get_data(osspath)
+    content = oss_client.get_data(osspath, [0,100])
 
     print('%s' % bold(magenta('Log Content:')))
     print(magenta('%s%s%s' % ('-'*20, logType, '-'*20)  ))
     if isinstance(content, bytes):
         content = str(content.decode('utf8'))
 
+
+
     if WIN and PY2:
         print(content)
     else:
@@ -409,7 +460,7 @@ def showLog(osspath, jobId, taskName, instanceId, logType):
             print(green(content))
         else:
             print(red(content))
-
+    print('......' if len(content)==101 else '')
 
     print(magenta('-'*46))
 
