@@ -1,14 +1,13 @@
-from terminal import red,confirm,blue,white
-from ..util import formater,config,oss_client
+from terminal import red,confirm,blue,white,green
+from ..util import config,oss_client,smart_unicode
 
 def delete(osspath, yes=False):
 
-    if osspath.find('oss://') != 0:
-        osspath = '%s%s' % (config.get_oss_path(), osspath)
+    # if osspath.find('oss://') != 0:
+    #     osspath = '%s%s' % (config.get_oss_path(), osspath)
 
     # list
-    (bucket,key) = oss_client.parse_oss_path(osspath)
-    (arr, pre_arr, bucket_tool) = oss_client.list(osspath)
+    (arr, pre_arr, bucket_tool, region, bucket, key) = oss_client.list(osspath)
 
     t=[]
     show_keys=[]
@@ -20,16 +19,16 @@ def delete(osspath, yes=False):
             if k.key!=key:
                 show_keys.append(k.key[klen:])
             else:
-                show_keys.append('.(%s)' % white(key))
+                show_keys.append('.(%s)' % (key))
     tlen = len(t)
 
 
     if tlen > 0:
         msg = "%s %s\n%s\n  %s\n%s" % (blue('Delete oss path' ),
-                                osspath,
+                                smart_unicode.format_utf8(osspath),
                                    'Found %s files' % tlen,
-                               '\n  '.join(show_keys),
-                               red('Delete all these %s files?' % tlen))
+                               smart_unicode.format_utf8('\n  '.join(show_keys)),
+                               (('Delete all these %s files' % tlen) if tlen > 1 else 'Delete this file'))
     else:
         print('Not found')
         return
@@ -38,4 +37,5 @@ def delete(osspath, yes=False):
         if tlen>0:
             bucket_tool.batch_delete_objects(t)
         bucket_tool.delete_object(key)
+        print(green('done'))
 
