@@ -1,6 +1,6 @@
-from ..util import config,oss_client,formater
+from ..util import config,oss_client,formater,smart_unicode
 from terminal import white,blue
-from ..const import CMD
+from ..const import CMD,WIN
 
 
 def ls(osspath=None, top=None, name=None):
@@ -14,14 +14,14 @@ def ls(osspath=None, top=None, name=None):
     if top:
         top = int(top)
 
-    if not osspath.startswith('oss://'):
-        osspath = def_oss_path + osspath
+    # if not osspath.startswith('oss://'):
+    #     osspath = def_oss_path + osspath
 
-    print(white('exec: %s o ls %s' % (CMD,osspath)))
 
-    (bucket, mykey) = oss_client.parse_oss_path(osspath)
+    (obj_arr, pre_arr, bucket_tool, region, bucket, mykey) = oss_client.list(osspath, '/')
+
+    print('exec: %s o ls oss://%s/%s' % (CMD, bucket, smart_unicode.format_utf8(mykey)))
 
-    (obj_arr, pre_arr, bucket_tool) = oss_client.list(osspath, '/')
 
     t=[]
     if search:
@@ -49,9 +49,9 @@ def ls(osspath=None, top=None, name=None):
                     t2.append(item)
     obj_arr = t2
 
-
     dlen = len(pre_arr)
     flen = len(obj_arr)
+
     if top:
         if top < dlen:
             pre_arr = pre_arr[:top]
@@ -59,10 +59,13 @@ def ls(osspath=None, top=None, name=None):
         elif top < dlen+flen:
             obj_arr = obj_arr[:top-dlen]
 
-
-    for item in pre_arr:
-        print('%s/' % blue(item))
+    if WIN:
+        for item in pre_arr:
+            print('%s/' % smart_unicode.format_utf8(item))
+    else:
+        for item in pre_arr:
+            print('%s/' % blue(item))
     for item in obj_arr:
         size = formater.format_size(item.size)
-        print('%s %s' % (item.key, white('(%s)'%size)))
+        print('%s %s' % (smart_unicode.format_utf8(item.key), white('(%s)'%size)))
 
