@@ -1,6 +1,5 @@
 import os
 from ..util import client, zip,oss_client,config
-from ..const import IMG_ID,INS_TYPE
 from terminal import green,white
 import re
 import json
@@ -71,9 +70,13 @@ def update_image_n_instype(p):
 
     with open(p, 'w') as f:
         ts = obj['DAG']['Tasks']
+
+        img_id = config.get_default_image()
+        ins_type = config.get_default_instance_type()
+
         for k in ts:
-            ts[k]['AutoCluster']['ECSImageId']=IMG_ID
-            ts[k]['AutoCluster']['InstanceType']=INS_TYPE
+            ts[k]['AutoCluster']['ImageId']=img_id
+            ts[k]['AutoCluster']['InstanceType']=ins_type
         f.write(json.dumps(obj, indent=2))
 
 def download_worker(packageUri, dist):
