@@ -6,7 +6,7 @@ import json
 def add_task(task, docker_image=None, cluster=None):
     util.check_is_job_project()
 
-    with open( 'job.json') as f:
+    with open('job.json') as f:
         job_desc = json.loads(f.read())
 
     desc_map = job_desc.get('DAG').get('Tasks')
@@ -17,8 +17,6 @@ def add_task(task, docker_image=None, cluster=None):
 
 def genTask(task_name, docker_image, cluster):
 
-    obj = util.parse_cluster_cfg(cluster)
-
     return {
         "ClusterId": "",
         "InstanceCount": 1,
@@ -35,5 +33,8 @@ def genTask(task_name, docker_image, cluster):
           "StdoutRedirectPath": ""
         },
         "Timeout": 21600,
-        "AutoCluster":obj
-    }
\ No newline at end of file
+        "AutoCluster":cluster
+    }
+
+def trans_cluster(cluster=None):
+    return util.parse_cluster_cfg(cluster)
