@@ -1,5 +1,5 @@
 
-from terminal import green,gray
+from terminal import green,white
 import json
 from ..util import util
 
@@ -61,12 +61,4 @@ def trans_cluster(cluster=None):
     return util.parse_cluster_cfg(cluster)
 
 def trans_docker(docker=None):
-    if docker.startswith('oss://'):
-        [k,v]=docker[6:].split(':',1)
-        k = 'oss://%s' % k
-
-        if not v.startswith('localhost:5000/'):
-            v = 'localhost:5000/%s' % v
-        return {"BATCH_COMPUTE_DOCKER_IMAGE":v, "BATCH_COMPUTE_DOCKER_REGISTRY_OSS_PATH":k}
-    else:
-        raise Exception('Invalid docker option format')
+    return util.trans_docker(docker)
