@@ -123,9 +123,13 @@ def create():
     cmd_create_cluster.option("--notification_events [cluster_events]",
                               MSG['create_cluster']['option']['notification_events'],
                               resolve=cluster_create.trans_notification_events)
-    cmd_create_cluster.option("--no_cache_support",
-                              MSG['create_cluster']['option']['no_cache_support'])
-
+    cmd_create_cluster.option("--locale [locale]", MSG['create_cluster']['option']['locale'])
+    cmd_create_cluster.option("--lock", MSG['create_cluster']['option']['lock'])
+    cmd_create_cluster.option("--no_cache_support", MSG['create_cluster']['option']['no_cache_support'])
+    cmd_create_cluster.option("--cache_block_size [cache_block_size]", MSG['create_cluster']['option']['cache_block_size'], resolve=cluster_create.trans_to_int)
+    cmd_create_cluster.option("--cache_total_size [cache_total_size]", MSG['create_cluster']['option']['cache_total_size'], resolve=cluster_create.trans_to_int)
+    cmd_create_cluster.option("--refresh_time_out [refresh_time_out]", MSG['create_cluster']['option']['refresh_time_out'], resolve=cluster_create.trans_to_int)
+    cmd_create_cluster.option("--nas_meta_cache", MSG['create_cluster']['option']['nas_meta_cache'])
     cmd_create_cluster.option("--vpc_cidr_block [vpc_cidr_block]",
                               MSG['create_cluster']['option']['vpc_cidr_block'])
     cmd_create_cluster.option("--vpc_id [vpc_id]",
