@@ -46,7 +46,8 @@ def __get_json():
                 'god': "使用上帝模式, 可选范围:[true|false]",
                 'ssl': '使用https访问BatchCompute, 可选范围:[true|false]',
                 'qsubuser': '设置qsub用户名, 如果不设置,默认:root',
-                'vpc_cidr_block': '设置使用VPC的CIDR IP段, 默认为: 192.168.0.0/16, 如果设置为false, 则使用经典网络' 
+                'vpc_cidr_block': '设置使用VPC的CIDR IP段, 默认为: 192.168.0.0/16, 如果设置为false, 则使用经典网络',
+                'networktype': '当前机器运行的网络环境，可以设置为"VPC"或者"Public",设置"VPC"表示当前环境为阿里云内网，到批量计算或者oss的请求走阿里云内网'
             }
         },
         'info': {
@@ -169,7 +170,13 @@ def __get_json():
                                              也支持直接挂载文件, 如:oss://path/to/mount/a.txt:/home/admin/nasdir/a.txt。""",
                 'nas_access_group': 'NAS 权限组',
                 'nas_file_system': 'NAS 文件系统',
+                'locale': '可选，挂载nas或者oss路径到本地时，使用的字符编码集',
+                'lock': '可选, 挂载nas或者oss路径到本地时，是否使用锁',
                 'no_cache_support': '可选, 取消OSSMounter缓存',
+                'cache_block_size': '可选, 使用OSSMounter时，设置的cache的块大小，单位: bytes，默认值 1024 * 256 bytes',
+                'cache_total_size': '可选, 使用OSSMounter时，设置的cache的总大小，单位: bytes，默认值 1024 * 1024 * 512 bytes',
+                'nas_meta_cache': '可选, 使用OSSMounter时，是否打开元数据cache，默认关闭',
+                'refresh_time_out': '可选, 使用OSSMoutner时，元数据cache的刷新周期， 单位: 秒',
                 'vpc_cidr_block': 'IP网段,如: 192.168.0.0/16',
                 'vpc_id': '设置 VPC id',
                 'show_json': '只显示cluster json不创建',
