@@ -327,7 +327,8 @@ def list_instance_types():
     itmap = it_config.get()
     t=[]
     for n in arr:
-        t.append( itmap[n] if itmap.get(n) else {'name':str(n),'cpu': -1,'memory':-1} )
+        if itmap.get(n):
+            t.append(itmap[n])
     t = formater.order_by(t, ['cpu','memory'],False)
 
     return t
@@ -339,7 +340,8 @@ def list_spot_instance_types():
     itmap = it_config.get()
     t = []
     for n in arr:
-        t.append(itmap[n] if itmap.get(n) else {'name': str(n), 'cpu': -1, 'memory': -1})
+        if itmap.get(n):
+            t.append(itmap[n])
     t = formater.order_by(t, ['cpu', 'memory'], False)
     return t
 
