@@ -21,7 +21,7 @@ COMMON = 'common'
 
 ALL = ['region','accesskeyid','accesskeysecret','osspath','locale','ssl','god',
                               'defaultimage','defaulttype','defaultcluster','version',
-                              'oss_region','oss_key','oss_id','qsubuser']
+                              'oss_region','oss_key','oss_id','qsubuser','vpc_cidr_block', 'localhostnetworktype']
 
 def getConfigs(section, keys=ALL):
     '''
@@ -128,4 +128,5 @@ def get_default_instance_cluster():
     img = getConfigs(COMMON, ['defaultcluster']).get('defaultcluster')
     if not img:
         raise Exception('No found default cluster\n  using:"bcs set -c <cluster-id>" to set default cluster\n  type: "bcs set -h" for more help')
-    return img
\ No newline at end of file
+    return img
+
