@@ -10,6 +10,7 @@ from ..util import config
 import re
 from ..const import WIN,PY2
 from os.path import getsize
+import os
 
 REG = r'^([\w\-]+)#oss:\/\/'
 
@@ -33,14 +34,22 @@ def get_endpoint(region):
 
 def check_client(cfg=None):
 
-    cfg = cfg or __get_cfg()
-    services = _get_service( cfg.get('oss_region') or cfg.get('region'),
-                                  cfg.get('oss_id') or cfg.get('accesskeyid'),
-                                  cfg.get('oss_key') or cfg.get('accesskeysecret'),
-                             connect_timeout=3)
+    if not (cfg.get("osspath") and cfg["osspath"]):
+        return "ok"
 
     try:
-        services.list_buckets()
+        path = os.path.dirname(config.get_cfg_path())
+        tmpFile = os.path.join(path, "tmp.txt")
+        cmd = "touch %s" % tmpFile
+        rc = os.system(cmd)
+        upload_file(tmpFile, cfg["osspath"])
+        if cfg["osspath"].endswith("/"):
+            objName = "%s%s" % (cfg["osspath"], "tmp.txt")
+        else:
+            objName = "%s/%s" % (cfg["osspath"], "tmp.txt")
+        delete_file(objName)
+        cmd = "rm -rf %s" % tmpFile
+        os.system(cmd)
     except Exception as e:
         raise Exception(e.message)
     return 'ok'
